@@ -39,7 +39,8 @@ sub generate_to {
 sub generate {
     my ($class, %args) = @_;
     my $mappings = do {
-        package Data::Dumper;
+        package # hide from PAUSE indexer
+            Data::Dumper;
 
         our ($Terse, $Indent, $Purity, $Deepcopy, $Pad, $Sortkeys);
         local $Terse = 1;
@@ -191,7 +192,7 @@ Google::ProtocolBuffers::Dynamic::MakeModule
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
